<h1>MLib</h1>

MLib is a simple python library made by a 12th degrees french student, for others 12 and 13th degrees students with the ISN speciality education.
It use pygame to displays graphics content.
For now, the main goal is to provide a GUI library.

For more documentation, go to this website (he is written in french) : https://matto.glitch.me/?mlib=go.

<h2>MGui</h2>

MGui allows the use of an GUI to make easily a GUI app.